@@ -774,21 +774,25 @@ function (iW, with.names)
 .MultipleAlignment.show_frame_line <-
 function (x, i, iW)
 {
-    snippetWidth <- getOption("width") - 2 - iW
+    snippetWidth <- getOption("width") - 2L - iW
     if (!is.null(names(x))) 
-        snippetWidth <- snippetWidth - .namesW - 1
-    seq_snippet <- toSeqSnippet(x[[i]], snippetWidth)
-    if (!is.null(names(x))) 
-        seq_snippet <- format(seq_snippet, width=snippetWidth)
-    cat(format(paste("[", i, "]", sep=""), width=iW, justify="right"),
-        " ", seq_snippet, sep="")
+        snippetWidth <- snippetWidth - .namesW - 1L
+    snippet <- toSeqSnippet(x[[i]], snippetWidth)
+    if (!is.null(names(x))) {
+        snippet_class <- class(snippet)
+        snippet <- format(snippet, width=snippetWidth)
+        class(snippet) <- snippet_class
+    }
+    cat(format(paste("[", i, "]", sep=""), width=iW, justify="right"), " ",
+        add_colors(snippet), sep="")
     if (!is.null(names(x))) {
         snippet_name <- names(x)[i]
         if (is.na(snippet_name))
             snippet_name <- "<NA>"
         else if (nchar(snippet_name) > .namesW)
-            snippet_name <-
-              paste(substr(snippet_name, 1, .namesW - 3), "...", sep="")
+            snippet_name <- paste0(substr(snippet_name, 1L, .namesW - 3L),
+                                   #compact_ellipsis)
+                                   "...")
         cat(" ", snippet_name, sep="")
     }
     cat("\n")
